@@ -15,7 +15,7 @@ class Project():
 
         #ensure that the project path is on sys.path
         self.PROJECT_PATH in sys.path or sys.path.insert(0,self.PROJECT_PATH)
-
+        self.get_settings()
 
     def __unicode__(self):
         s = 'Django Backstage project named %s at %s' % (self.PROJECT_NAME, self.PROJECT_PATH)
@@ -108,7 +108,16 @@ class Project():
             raise
         return True
 
-def copy_project_skel(project_dir):
+    def build_virtualenv(self):
+        """build the virtual environment for this backstage project"""
+        venvdir = os.path.join(self.PROJECT_ROOT,'project/virtualenv')
+        cmd = '%s/build_virtualenv' % (venvdir)
+        os.system('virtualenv --no-site-packages %s' % venvdir)
+        execfile(os.path.join(venvdir,'bin/activate_this.py'))
+        return
+
+
+def copy_project_skel(project_path):
     """Populate a (usually) new backstage project with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel')
     if not os.path.exists(skeldir):
@@ -118,10 +127,10 @@ def copy_project_skel(project_dir):
     try:
         #Copy the contents of the 'base' folder into the project root
         skelbase=os.path.join(skeldir, 'base')
-        os.system("cp -rpv %s/* %s" % (skelbase, project_dir))
+        os.system("cp -rpv %s/* %s" % (skelbase, project_path))
 
     except:
-        s = "ERROR copying the project skel into %s" % project_dir
+        s = "ERROR copying the project skel into %s" % project_path
         print s
         raise
     return True
@@ -220,3 +229,4 @@ def use_project(project_root):
     print s
     return backstage_project
 
+
